scipy.stats.gaussian_kde
========================

.. currentmodule:: scipy.stats

.. autoclass:: gaussian_kde

   

   .. HACK
      .. autosummary::
         :toctree:
      
         gaussian_kde.__init__
         gaussian_kde.covariance_factor
         gaussian_kde.evaluate
         gaussian_kde.integrate_box
         gaussian_kde.integrate_box_1d
         gaussian_kde.integrate_gaussian
         gaussian_kde.integrate_kde
         gaussian_kde.resample
         gaussian_kde.scotts_factor
         gaussian_kde.silverman_factor



   

